==> portal-contribuinte-3.270.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/atendimento/findByContribuinteAtendimento.sql <==
SELECT PESSOASGROUP.CODIGOPESSOA,
       PESSOASGROUP.TIPOPESSOA,
       PESSOASGROUP.NOME,
       PESSOASGROUP.CNPJCPF,
       COUNT(DISTINCT PESSOASGROUP.QUANTIDADECADASTROS) AS QUANTIDADECADASTROS,
       PESSOASGROUP.CONTATOID,
       PESSOASGROUP.CONTATOCODIGO,
       PESSOASGROUP.TELEFONECELULAR,
       PESSOASGROUP.TELEFONERESIDENCIAL,
       PESSOASGROUP.TELEFONECOMERCIAL 
FROM (
 SELECT
       PESSOA.PESSOA AS CODIGOPESSOA,
       PESSOA.TIPOPESSOA AS TIPOPESSOA,
       PESSOA.NOME AS NOME,
       PESSOA.CNPJ_CPF AS CNPJCPF,
       CG.IDKEY AS QUANTIDADECADASTROS,
       CP.IDKEY AS CONTATOID,
       CP.SEQUENCIA AS CONTATOCODIGO,
       CP.TELEFONECELULAR AS TELEFONECELULAR,
       CP.TELEFONERESIDENCIAL AS TELEFONERESIDENCIAL,
       CP.TELEFONECOMERCIAL AS TELEFONECOMERCIAL 
 FROM PESSOA PESSOA 
 LEFT OUTER JOIN TRIBPROPRIETARIO PROP ON PESSOA.PESSOA = PROP.PESSOA
 JOIN TRIBCADASTROGERAL CG
  	 ON PROP.TIPOCADASTRO = CG.TIPOCADASTRO
 	AND PROP.CADASTROGERAL = CG.CADASTROGERAL
 LEFT JOIN CONTATOPESSOA CP 
     ON CP.PESSOA = PESSOA.PESSOA 
 WHERE (PESSOA.CNPJ_CPF LIKE :search OR UPPER(PESSOA.NOME) LIKE :search OR CAST(PESSOA.PESSOA AS VARCHAR) LIKE :search )
 	AND CG.EXCLUSAOLOGICA = 'N' 
 	AND (CP.SEQUENCIA = PESSOA.SEQUENCIACONTATO OR CP.SEQUENCIA IS NULL) 
 
UNION ALL

 SELECT 
       PESSOA.PESSOA AS CODIGOPESSOA,
       PESSOA.TIPOPESSOA AS TIPOPESSOA,
       PESSOA.NOME AS NOME,
       PESSOA.CNPJ_CPF AS CNPJCPF,
       CG.IDKEY AS QUANTIDADECADASTROS,
       CP.IDKEY AS CONTATOID,
       CP.SEQUENCIA AS CONTATOCODIGO,
       CP.TELEFONECELULAR AS TELEFONECELULAR,
       CP.TELEFONERESIDENCIAL AS TELEFONERESIDENCIAL,
       CP.TELEFONECOMERCIAL AS TELEFONECOMERCIAL 
 FROM PESSOA PESSOA 
 JOIN TRIBCADASTROGERAL CG
 ON CG.PESSOA = PESSOA.PESSOA
 LEFT JOIN CONTATOPESSOA CP 
     ON CP.PESSOA = PESSOA.PESSOA 
 WHERE (PESSOA.CNPJ_CPF LIKE :search OR UPPER(PESSOA.NOME) LIKE :search OR CAST(PESSOA.PESSOA AS VARCHAR) LIKE :search )
 	AND CG.EXCLUSAOLOGICA = 'N' 
 	AND (CP.SEQUENCIA = PESSOA.SEQUENCIACONTATO OR CP.SEQUENCIA IS NULL) 
) PESSOASGROUP 
GROUP BY 
       PESSOASGROUP.CODIGOPESSOA,
       PESSOASGROUP.TIPOPESSOA,
       PESSOASGROUP.NOME,
       PESSOASGROUP.CNPJCPF,
       PESSOASGROUP.CONTATOID,
       PESSOASGROUP.CONTATOCODIGO,
       PESSOASGROUP.TELEFONECELULAR,
       PESSOASGROUP.TELEFONERESIDENCIAL,
       PESSOASGROUP.TELEFONECOMERCIAL

==> portal-contribuinte-3.317.1.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/atendimento/findByContribuinteAtendimento.sql <==
SELECT PESSOASGROUP.CODIGOPESSOA,
       PESSOASGROUP.TIPOPESSOA,
       PESSOASGROUP.NOME,
       PESSOASGROUP.CNPJCPF,
       COUNT(DISTINCT PESSOASGROUP.QUANTIDADECADASTROS) AS QUANTIDADECADASTROS,
       PESSOASGROUP.CONTATOID,
       PESSOASGROUP.CONTATOCODIGO,
       PESSOASGROUP.TELEFONECELULAR,
       PESSOASGROUP.TELEFONERESIDENCIAL,
       PESSOASGROUP.TELEFONECOMERCIAL 
FROM (
 SELECT
       PESSOA.PESSOA AS CODIGOPESSOA,
       PESSOA.TIPOPESSOA AS TIPOPESSOA,
       PESSOA.NOME AS NOME,
       PESSOA.CNPJ_CPF AS CNPJCPF,
       CG.IDKEY AS QUANTIDADECADASTROS,
       CP.IDKEY AS CONTATOID,
       CP.SEQUENCIA AS CONTATOCODIGO,
       CP.TELEFONECELULAR AS TELEFONECELULAR,
       CP.TELEFONERESIDENCIAL AS TELEFONERESIDENCIAL,
       CP.TELEFONECOMERCIAL AS TELEFONECOMERCIAL 
 FROM PESSOA PESSOA 
 LEFT OUTER JOIN TRIBPROPRIETARIO PROP ON PESSOA.PESSOA = PROP.PESSOA
 JOIN TRIBCADASTROGERAL CG
  	 ON PROP.TIPOCADASTRO = CG.TIPOCADASTRO
 	AND PROP.CADASTROGERAL = CG.CADASTROGERAL
 LEFT JOIN CONTATOPESSOA CP 
     ON CP.PESSOA = PESSOA.PESSOA 
 WHERE (PESSOA.CNPJ_CPF LIKE :search OR UPPER(PESSOA.NOME) LIKE :search OR CAST(PESSOA.PESSOA AS VARCHAR) LIKE :search )
 	AND CG.EXCLUSAOLOGICA = 'N' 
 	AND (CP.SEQUENCIA = PESSOA.SEQUENCIACONTATO OR CP.SEQUENCIA IS NULL) 
 
UNION ALL

 SELECT 
       PESSOA.PESSOA AS CODIGOPESSOA,
       PESSOA.TIPOPESSOA AS TIPOPESSOA,
       PESSOA.NOME AS NOME,
       PESSOA.CNPJ_CPF AS CNPJCPF,
       CG.IDKEY AS QUANTIDADECADASTROS,
       CP.IDKEY AS CONTATOID,
       CP.SEQUENCIA AS CONTATOCODIGO,
       CP.TELEFONECELULAR AS TELEFONECELULAR,
       CP.TELEFONERESIDENCIAL AS TELEFONERESIDENCIAL,
       CP.TELEFONECOMERCIAL AS TELEFONECOMERCIAL 
 FROM PESSOA PESSOA 
 JOIN TRIBCADASTROGERAL CG
 ON CG.PESSOA = PESSOA.PESSOA
 LEFT JOIN CONTATOPESSOA CP 
     ON CP.PESSOA = PESSOA.PESSOA 
 WHERE (PESSOA.CNPJ_CPF LIKE :search OR UPPER(PESSOA.NOME) LIKE :search OR CAST(PESSOA.PESSOA AS VARCHAR) LIKE :search )
    AND CG.EXCLUSAOLOGICA = 'N'
    AND (CP.SEQUENCIA = PESSOA.SEQUENCIACONTATO OR CP.SEQUENCIA IS NULL)

 UNION ALL
 SELECT
       PESSOA.PESSOA AS CODIGOPESSOA,
       PESSOA.TIPOPESSOA AS TIPOPESSOA,
       PESSOA.NOME AS NOME,
       PESSOA.CNPJ_CPF AS CNPJCPF,
       CG.IDKEY AS QUANTIDADECADASTROS,
       CP.IDKEY AS CONTATOID,
       CP.SEQUENCIA AS CONTATOCODIGO,
       CP.TELEFONECELULAR AS TELEFONECELULAR,
       CP.TELEFONERESIDENCIAL AS TELEFONERESIDENCIAL,
       CP.TELEFONECOMERCIAL AS TELEFONECOMERCIAL
 FROM PESSOA PESSOA
 JOIN TRIBCONTRATOSOCIALPESSOA CSP ON CSP.PESSOA = PESSOA.PESSOA
 JOIN TRIBCONTRATOSOCIAL CS ON CS.IDKEY = CSP.TRIBCONTRATOSOCIAL_IDKEY
 JOIN TRIBCADASTROMOBILIARIO CM ON CM.TRIBCADASTROGERAL_IDKEY = CS.TRIBCADASTROMOBILIARIO_IDKEY
 JOIN TRIBCADASTROGERAL CG ON CG.IDKEY = CM.TRIBCADASTROGERAL_IDKEY
 LEFT JOIN CONTATOPESSOA CP
     ON CP.PESSOA = PESSOA.PESSOA
 WHERE (PESSOA.CNPJ_CPF LIKE :search OR UPPER(PESSOA.NOME) LIKE :search OR CAST(PESSOA.PESSOA AS VARCHAR) LIKE :search )
    AND CG.EXCLUSAOLOGICA = 'N'
    AND (CP.SEQUENCIA = PESSOA.SEQUENCIACONTATO OR CP.SEQUENCIA IS NULL)
    AND :consideraContratoSocial = true

) PESSOASGROUP 
GROUP BY 
       PESSOASGROUP.CODIGOPESSOA,
       PESSOASGROUP.TIPOPESSOA,
       PESSOASGROUP.NOME,
       PESSOASGROUP.CNPJCPF,
       PESSOASGROUP.CONTATOID,
       PESSOASGROUP.CONTATOCODIGO,
       PESSOASGROUP.TELEFONECELULAR,
       PESSOASGROUP.TELEFONERESIDENCIAL,
       PESSOASGROUP.TELEFONECOMERCIAL
